from setuptools import setup, find_packages

setup(
    name='phd-utils',
    version='0.1.3',
    description='A collection of utilities for PhD students',
    author='Henrique Weber',
    packages=find_packages(),
    install_requires=[
      
    ],
)
